// ========================================================================================
//	TTreeView.h				 	Copyright (C) 2001-2002 Mike Lockwood. All rights reserved.
// ========================================================================================
/*
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef __TTreeView__
#define __TTreeView__

#include "TGridView.h"
#include "TList.h"

class TTreeNode;

class TTreeView : public TGridView
{
public:
							TTreeView(TWindow* parent, const TRect& bounds, int columnCount);

	virtual void			Create();
	virtual int				GetRowCount() const;
	virtual int				GetColumnCount() const;
	virtual TCoord			GetRowHeight(int row) const;
	virtual TCoord			GetColumnWidth(int column) const;

	virtual bool			IsColumnResizable(int column) const;
	virtual void			SetColumnWidth(int column, TCoord width);

	void					DeleteAllNodes();

protected:				
	virtual					~TTreeView();

	virtual void			DrawCell(int row, int column, const TRect& cellBounds, TDrawContext& context);

	virtual void			DoMouseDown(const TPoint& point, TMouseButton button, TModifierState state);
	virtual void			DoMouseUp(const TPoint& point, TMouseButton button, TModifierState state);
	virtual void			DoMouseMoved(const TPoint& point, TModifierState state);
	virtual bool			DoKeyDown(KeySym key, TModifierState state, const char* string);

	void					ExpandCollapseRow(int row);
	void					ExpandRow(int& row);

protected:
	TList<TTreeNode>		fRowList;
	TCoord					fRowHeight;
	TCoord*					fColumnWidths;
	int						fColumnCount;			
	int						fTrackingRow;		// row we are tracking a click on, or -1
	bool					fTriangleTurning;	// true if we should draw fTrackingRow as partially turned triangle
};

#endif // __TTreeView__
