// ========================================================================================
//	TSyntaxTextView.h		 	Copyright (C) 2001-2002 Mike Lockwood. All rights reserved.
// ========================================================================================
/*
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef __TSyntaxTextView__
#define __TSyntaxTextView__

#include "fw/TTextView.h"
#include "TSyntaxScanner.h"
#include "TLanguage.h"

class TSettingsFile;


class TSyntaxTextView : public TTextView
{
public:
								TSyntaxTextView(TWindow* parent, const TRect& bounds, TFont* font, bool modifiable);
	
	void						SetUseSyntaxHiliting(bool doit);
	inline void					SetLanguage(ELanguage language) { fLanguage = language; }

	static void					ReadFromSettingsFile(TSettingsFile* settingsFile);
	static void					WriteToSettingsFile(TSettingsFile* settingsFile);

protected:
	virtual						~TSyntaxTextView();

	// TTextView overrides
	virtual void				RedrawLines(uint32 startLine, uint32 endLine, bool showHideInsertionPoint, TRegion* clip = NULL);
	virtual void				DrawText(const TChar* text, int length, TDrawContext& context);
	virtual void				SetSelection(STextOffset start, STextOffset end, bool redraw = true);
	
	void						NextSyntaxState();
	bool						IsKeyword(const TChar* text, uint32 length);

protected:
	ELanguage					fLanguage;
	bool						fUseSyntaxHiliting;
	TSyntaxScanner				fSyntaxScanner;
	TSyntaxScanner::TScanState	fSyntaxState;
	STextOffset					fSyntaxOffset;
	uint32						fSyntaxLength;
	
	TSyntaxScanner::TScanState	fCachedSyntaxScanStateStart;	// cached scan state at start of selection
	TSyntaxScanner::TScanState	fCachedSyntaxScanStateEnd;		// cached scan state at line after end of selection
	
	static TColor				sCommentColor;
	static TColor				sPreprocessorColor;
	static TColor				sKeywordColor;
	static TColor				sStringColor;

	static TColor				sForeColor;
	static TColor				sBackColor;
	
	static bool					sUseSyntaxHiliting;
};

#endif // __TEditorTextView__
