// ========================================================================================
//	TTextWindowsMenu.cpp		Copyright (C) 2001-2003 Mike Lockwood. All rights reserved.
// ========================================================================================
/*
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "IDECommon.h"

#include "TTextWindowsMenu.h"
#include "TTextDocument.h"
#include "fw/TDocumentWindow.h"


TTextWindowsMenu::TTextWindowsMenu()
	:	TPopupMenu(NULL)
{
}


TTextWindowsMenu::~TTextWindowsMenu()
{
}


void TTextWindowsMenu::PreDisplayMenu()
{
	int32 size = fItemList.GetSize();
	
	while (size > 0)
	{
		fItemList.DeleteAt(size - 1);
		size--;
	}
	
	TPopupMenu::PreDisplayMenu();

	TListIterator<TTopLevelWindow> iter(TTopLevelWindow::GetWindowList());
	TTopLevelWindow* window;

	while ((window = iter.Next()) != NULL)
	{
		TDocumentWindow* documentWindow = dynamic_cast<TDocumentWindow *>(window);
		
		if (documentWindow)
		{
			TTextDocument* document = dynamic_cast<TTextDocument *>(documentWindow->GetWindowContext());
			
			if (document)
			{
				TMenuItem* item = new TMenuItem(document->GetFile().GetPath());
				item->Enable(true);
				AddItem(item);
			}
		}
	}
}


void TTextWindowsMenu::MenuItemSelected(TMenu* menu, int itemIndex, Time time)
{
}


TTextWindowsMenuBehavior::TTextWindowsMenuBehavior(TWindow* window)
	:	fWindow(window)
{
}


TTextWindowsMenuBehavior::~TTextWindowsMenuBehavior()
{
}

bool TTextWindowsMenuBehavior::DoMouseDown(const TPoint& point, TMouseButton button, TModifierState state)
{
	if (button == kRightButton)
	{
		TTextWindowsMenu* menu = new TTextWindowsMenu();
		
		menu->Display(fWindow, point, fWindow->GetCurrentEventTime());
		
		return true;
	}
	else
		return false;
};

